@@ -71,7 +71,8 @@ def w2p(dispersion,w,extrapolate=True):
          x = w2p(disp,w)
 
     """
-    x = interp1d(dispersion,np.arange(len(dispersion)),kind='cubic',bounds_error=False,fill_value=(np.nan,np.nan),assume_sorted=False)(w)
+    x = interp1d(dispersion,np.arange(len(dispersion)),kind='cubic',bounds_error=False,
+                 fill_value=(np.nan,np.nan),assume_sorted=False)(w)
     # Need to extrapolate
     if ((np.min(w)<np.min(dispersion)) | (np.max(w)>np.max(dispersion))) & (extrapolate is True):
         win = dispersion
@@ -125,7 +126,8 @@ def p2w(dispersion,x,extrapolate=True):
     """
 
     npix = len(dispersion)
-    w = interp1d(np.arange(len(dispersion)),dispersion,kind='cubic',bounds_error=False,fill_value=(np.nan,np.nan),assume_sorted=False)(x)
+    w = interp1d(np.arange(len(dispersion)),dispersion,kind='cubic',bounds_error=False,
+                 fill_value=(np.nan,np.nan),assume_sorted=False)(x)
     # Need to extrapolate
     if ((np.min(x)<0) | (np.max(x)>(npix-1))) & (extrapolate is True):
         xin = np.arange(npix)
@@ -696,9 +698,12 @@ def specprep(spec):
     if spec.mask is not None:
         # Set errors to high value, leave flux alone
         spec.err[spec.mask] = 1e30
+
     # Fix any NaNs in flux
     bd = np.where(~np.isfinite(spec.flux))
     if len(bd[0])>0:
+        if spec.mask is None:
+            spec.mask = np.zeros(spec.shape,bool)
         if spec.norder>1:
             spec.flux[bd[0],bd[1]] = 0.0
             spec.err[bd[0],bd[1]] = 1e30
@@ -708,26 +713,31 @@ def specprep(spec):
             spec.err[bd[0]] = 1e30
             spec.mask[bd[0]] = True
 
+    # Mask bad pixels
+    snr = spec.flux/spec.err
+    bdpix = (snr < 1e-10)
+    if np.sum(bdpix)>0:
+        if spec.mask is None:
+            spec.mask = np.zeros(spec.shape,bool)            
+            spec.mask[bdpix] = True
+    
     # Check for orders that are entirely masked
     if spec.norder>1:
         ngood = np.sum(~spec.mask,axis=0)
         bdorder, = np.where(ngood==0)
         if len(bdorder)==spec.norder:
             raise ValueError('Entire spectrum is masked')
-        if len(bdorder)>0:
-            print('Removing order '+str(bdorder)+' that are entirely masked')
-            np.delete(spec.flux,bdorder,axis=1)
-            np.delete(spec.err,bdorder,axis=1)
-            np.delete(spec.wave,bdorder,axis=1)
-            np.delete(spec.mask,bdorder,axis=1)
-            np.delete(spec.lsf.wave,bdorder,axis=1)
-            np.delete(spec.lsf.pars,bdorder,axis=1)
-            spec.norder -= 1
+        #if len(bdorder)>0:
+        #    print('Removing order '+str(bdorder)+' that are entirely masked')
+        #    spec.remove_order(bdorder)
     else:
         ngood = np.sum(~spec.mask)
         if ngood==0:
             raise ValueError('Entire spectrum is masked')
-            
+
+    # Remove any blank spectra
+    spec.remove_blank_orders(verbose=True)
+        
     # normalize spectrum
     if spec.normalized is False: spec.normalize()  
 
@@ -840,8 +850,15 @@ def maskdiscrepant(spec,model,nsig=10,verbose=False):
     """
 
     print = getprintfunc() # Get print function to be used locally, allows for easy logging
-    
-    spec2 = spec.copy()
+
+    if model is None or hasattr(model,'flux')==False:
+        return spec
+
+    try:
+        spec2 = spec.copy()
+    except:
+        print('problem')
+        import pdb; pdb.set_trace()
     wave = spec2.wave.copy().reshape(spec2.npix,spec2.norder)   # make 2D
     flux = spec2.flux.copy().reshape(spec2.npix,spec2.norder)   # make 2D
     err = spec2.err.copy().reshape(spec2.npix,spec2.norder)     # make 2D
